@@ -59,7 +59,7 @@ class Command(BaseCommand):
         sysStr = platform.system()
         if sysStr == "Linux":
             # healthcheck
-            checkName = "%s %s" % (getattr(settings, "APP_NAME", "[Unknown]"), command)
+            checkName = "[%s] %s" % (getattr(settings, "APP_NAME", "Unknown"), command)
             headers = {
                 "X-Api-Key": HEALTHCHECK_API_KEY,
             }
