@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12506 2020-09-04 05:40:25Z Lavender $
+# $Id: __init__.py 12541 2020-10-07 17:14:18Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-09-04 14:40:25 +0900 (週五, 04 九月 2020) $
-# $Revision: 12506 $
+# $Date: 2020-10-08 02:14:18 +0900 (週四, 08 十月 2020) $
+# $Revision: 12541 $
 
 import os
 import re
@@ -210,6 +210,17 @@ def attachSettings(settingsDict, enablePaypal=False):
 
     extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE_CLASSES,
                             key='django.middleware.security.SecurityMiddleware')
+       
+
+    # 加上這個是為了處理付款回傳時造成 session id 遺失問題(SAMESITE)，因此在提交
+    # 付款表單時，先記錄哪個 basket 對哪個 sessionKey，當付款回來後將 request.session
+    # 拿回來
+    ADDING_MIDDLEWARE_CLASSES2 = (
+        'Iuno.shop.middleware.PaymentSessionMiddleware',
+    )
+                            
+    extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE_CLASSES2,
+                            key='django.contrib.sessions.middleware.SessionMiddleware')
     #=========================================================================
     
     #=========================================================================
@@ -1091,6 +1102,14 @@ def buildAPIForm(submission, request, apiName, extra={}):
         form = mpg.buildForm(data)
         
     if apiName == ECPAY_MAP:
+        from Iuno.shop.models import TradeSession
+        TradeSession.objects.update_or_create(
+            basket=request.basket,
+            defaults={
+                'sessionKey': request.COOKIES.get(settings.SESSION_COOKIE_NAME),
+            }
+        )
+        
         temp = get_template('shop/payment/EcpayMap.html')
 
         if settings.ECPAY_SANDBOX_MODE:
@@ -1120,6 +1139,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
         if DJANGO_VERSION >= 11100: # django >= 1.11
             context = {
                 'apiUrl': apiUrl,
+                'basket': request.basket,
                 'chantID': settings.ECPAY_API_MERCHANT_ID,
                 'subTypes': subTypes,
                 'returnUrl': returnUrl,
@@ -1131,6 +1151,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
         else:
             context = Context({
                 'apiUrl': apiUrl,
+                'basket': request.basket,
                 'chantID': settings.ECPAY_API_MERCHANT_ID,
                 'subTypes': subTypes,
                 'returnUrl': returnUrl,
