@@ -21,6 +21,7 @@ User = get_user_model()
 Source = get_model('payment', 'Source')
 UserAddress = get_model('address', 'UserAddress')
 Order = get_model('order', 'Order')
+Basket = get_model('basket', 'Basket')
 ShippingAddress = get_model('order', 'ShippingAddress')
 
 ATM = 'ATM'
@@ -449,6 +450,14 @@ def get_messages(self, ctx=None):
     return originGetMessages(self, ctx=ctx)
         
 CommunicationEventType.get_messages = get_messages
+
+class TradeSession(models.Model):
+    basket = models.ForeignKey(
+        Basket,
+        verbose_name=_("Basket"),
+        on_delete=models.CASCADE,
+    )
+    sessionKey = models.CharField(max_length=255)
     
 class ECPayTrade(models.Model):
     merchantId = models.CharField(max_length=255)
